# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.3.0

import enum

import winrt.system
from winrt import _winrt_windows_perception_people

__all__ = [
    "HandJointKind",
    "JointPoseAccuracy",
    "HandMeshVertex",
    "JointPose",
    "EyesPose",
    "HandMeshObserver",
    "HandMeshVertexState",
    "HandPose",
    "HeadPose",
]

class HandJointKind(enum.IntEnum):
    PALM = 0
    WRIST = 1
    THUMB_METACARPAL = 2
    THUMB_PROXIMAL = 3
    THUMB_DISTAL = 4
    THUMB_TIP = 5
    INDEX_METACARPAL = 6
    INDEX_PROXIMAL = 7
    INDEX_INTERMEDIATE = 8
    INDEX_DISTAL = 9
    INDEX_TIP = 10
    MIDDLE_METACARPAL = 11
    MIDDLE_PROXIMAL = 12
    MIDDLE_INTERMEDIATE = 13
    MIDDLE_DISTAL = 14
    MIDDLE_TIP = 15
    RING_METACARPAL = 16
    RING_PROXIMAL = 17
    RING_INTERMEDIATE = 18
    RING_DISTAL = 19
    RING_TIP = 20
    LITTLE_METACARPAL = 21
    LITTLE_PROXIMAL = 22
    LITTLE_INTERMEDIATE = 23
    LITTLE_DISTAL = 24
    LITTLE_TIP = 25

class JointPoseAccuracy(enum.IntEnum):
    HIGH = 0
    APPROXIMATE = 1

HandMeshVertex = _winrt_windows_perception_people.HandMeshVertex
JointPose = _winrt_windows_perception_people.JointPose
EyesPose = _winrt_windows_perception_people.EyesPose
HandMeshObserver = _winrt_windows_perception_people.HandMeshObserver
HandMeshVertexState = _winrt_windows_perception_people.HandMeshVertexState
HandPose = _winrt_windows_perception_people.HandPose
HeadPose = _winrt_windows_perception_people.HeadPose
